import express from 'express';
import logger from 'morgan';
import serveIndex from 'serve-index';
import error from './error';
import { logInfo } from '../utils/logger';

const app = express();

export default function start(handler, assets, devConfig) {
    if (process.env.NODE_ENV === 'development') {
        app.use(logger('dev'));
        app.use('/public', serveIndex(assets));
        app.use(
            require('webpack-dev-middleware')(devConfig.webpackCompiler, { publicPath: '/' })
        );
        app.use(
            require('webpack-hot-middleware')(devConfig.webpackCompiler)
        );
    }

    app.use('/', express.static(assets));

    app.get('/*', handler);

    app.use(error);

    app.listen(3000, () => {
        logInfo('Server started.');
    });
}
